@@ -124,170 +124,215 @@
 <context>
     <name>FSWnd</name>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="13"/>
+        <location filename="../src/plugins/fs/fs.ui" line="16"/>
         <source>Filesharing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="32"/>
+        <location filename="../src/plugins/fs/fs.ui" line="35"/>
         <source>Status</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="165"/>
+        <location filename="../src/plugins/fs/fs.ui" line="168"/>
         <source>Clear inactive downloads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="236"/>
+        <location filename="../src/plugins/fs/fs.ui" line="239"/>
         <source>Clear</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="263"/>
+        <location filename="../src/plugins/fs/fs.ui" line="266"/>
         <source>Search and download</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="395"/>
+        <location filename="../src/plugins/fs/fs.ui" line="410"/>
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="298"/>
+        <location filename="../src/plugins/fs/fs.ui" line="301"/>
         <source>Search for:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="336"/>
+        <location filename="../src/plugins/fs/fs.ui" line="342"/>
         <source>with anonymity:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="363"/>
+        <location filename="../src/plugins/fs/fs.ui" line="375"/>
         <source>in Namespace:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="484"/>
+        <location filename="../src/plugins/fs/fs.ui" line="499"/>
         <source>Mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="499"/>
+        <location filename="../src/plugins/fs/fs.ui" line="514"/>
         <source>Indexing will avoid copying the file into the GNUnet database.  Instead, GNUnet will try to access the specified file directly.  If that fails, a copy of the file will be created.  Indexing should be used if the local machine is unlikely to ever be compromised by an adversary and if the uploaded file will not be modified or moved in the future.  Indexing is more efficient than insertion.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="502"/>
+        <location filename="../src/plugins/fs/fs.ui" line="517"/>
         <source>Index</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="515"/>
+        <location filename="../src/plugins/fs/fs.ui" line="530"/>
         <source>Inserting a file means that an encrypted copy will be added to the GNUnet database.  Without the proper key (which is not stored in plaintext anywhere) the file cannot be decrypted.  Use this option for small files, files that will be modified soon, files that maybe moved or if you are afraid that an adversary may detect the file in plaintext on your machine (after compromising your machine).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="518"/>
+        <location filename="../src/plugins/fs/fs.ui" line="533"/>
         <source>Insert</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="536"/>
+        <location filename="../src/plugins/fs/fs.ui" line="551"/>
         <source>Scope</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="548"/>
+        <location filename="../src/plugins/fs/fs.ui" line="566"/>
         <source>Single file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="558"/>
+        <location filename="../src/plugins/fs/fs.ui" line="579"/>
         <source>Entire directory</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="578"/>
+        <location filename="../src/plugins/fs/fs.ui" line="599"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="590"/>
+        <location filename="../src/plugins/fs/fs.ui" line="611"/>
         <source>Anonymity:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="600"/>
+        <location filename="../src/plugins/fs/fs.ui" line="621"/>
         <source>What level of sender-anonymity is desired when sharing this particular file?  0 allows direct connections (no anonymity).  Higher levels require increasing amounts of cover traffic per shared block, increasing your privacy at the expense of efficiency.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="672"/>
+        <location filename="../src/plugins/fs/fs.ui" line="696"/>
         <source>File-/Directoryname</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="684"/>
+        <location filename="../src/plugins/fs/fs.ui" line="708"/>
         <source>Filename:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="694"/>
+        <location filename="../src/plugins/fs/fs.ui" line="718"/>
         <source>Choose</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="768"/>
+        <location filename="../src/plugins/fs/fs.ui" line="792"/>
         <source>Start publication process</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="629"/>
+        <location filename="../src/plugins/fs/fs.ui" line="650"/>
         <source>Priority:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="51"/>
+        <location filename="../src/plugins/fs/fs.ui" line="54"/>
         <source>Searches</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="81"/>
+        <location filename="../src/plugins/fs/fs.ui" line="84"/>
         <source>Downloads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="143"/>
+        <location filename="../src/plugins/fs/fs.ui" line="146"/>
         <source>Abort selected downloads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="146"/>
+        <location filename="../src/plugins/fs/fs.ui" line="149"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="190"/>
+        <location filename="../src/plugins/fs/fs.ui" line="193"/>
         <source>Publications</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="233"/>
+        <location filename="../src/plugins/fs/fs.ui" line="236"/>
         <source>Clear completed publications</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="796"/>
+        <location filename="../src/plugins/fs/fs.ui" line="820"/>
         <source>Open file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/fs.ui" line="453"/>
+        <location filename="../src/plugins/fs/fs.ui" line="468"/>
         <source>Publication</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="316"/>
+        <source>Search term, e.g. &quot;GPL&quot; or &quot;application/jpg&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="618"/>
+        <source>Desired anonymity level. 0 means no receiver anonymity (allows direct connection).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="352"/>
+        <source>Specify the desired anonymity level for this download. A value of 0 means no receiver anonymity (allows direct connection).  Use higher values for increased privacy at the expense of performance.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="390"/>
+        <source>Restrict the search to a particular namespace. If empty, the global namespace is searched.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="511"/>
+        <source>Index file(s), do not store in encrypted database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="527"/>
+        <source>Insert file into encrypted database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="563"/>
+        <source>Publish a single file only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="576"/>
+        <source>Publish an entire directory including subdirectories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/fs/fs.ui" line="657"/>
+        <source>Importantance of the file (used to prioritize data in the local datastore).</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GAboutDlg</name>
@@ -581,7 +626,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/fs/uploadController.cc" line="140"/>
+        <location filename="../src/plugins/fs/uploadController.cc" line="118"/>
         <source>Internal error: failed to create meta data for publication.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -672,6 +717,14 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>GMainWindow</name>
+    <message>
+        <location filename="../src/core/wndMain.cc" line="71"/>
+        <source>Number of connected peers</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>GSearchItemDelegate</name>
     <message>
@@ -682,13 +735,16 @@
 </context>
 <context>
     <name>GStatsPlugin</name>
+</context>
+<context>
+    <name>GStatsThread</name>
     <message>
-        <location filename="../src/plugins/stats/statsPlugin.cc" line="77"/>
+        <location filename="../src/plugins/stats/statsThread.cc" line="63"/>
         <source>Error establishing connection with background process gnunetd.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/stats/statsPlugin.cc" line="92"/>
+        <location filename="../src/plugins/stats/statsThread.cc" line="82"/>
         <source>Error reading information from background process gnunetd.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -860,25 +916,20 @@ Detailed error information: assertion failed at %1:%2.</source>
 <context>
     <name>WndStats</name>
     <message>
-        <location filename="../src/plugins/stats/stats.ui" line="13"/>
+        <location filename="../src/plugins/stats/stats.ui" line="16"/>
         <source>Statistics</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/stats/stats.ui" line="38"/>
+        <location filename="../src/plugins/stats/stats.ui" line="41"/>
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/stats/stats.ui" line="43"/>
+        <location filename="../src/plugins/stats/stats.ui" line="46"/>
         <source>Value</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../src/plugins/stats/stats.ui" line="72"/>
-        <source>Refresh</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>dlgTextEditor</name>
