@@ -30,21 +30,23 @@
 #include <QObject>
 #include "gnunet_qt_common.h"
 #include "ui_stats.h"
+#include "statsThread.h"
 
 class GStatsPlugin : public GPlugin, public Ui::WndStats
 {
   Q_OBJECT
   
 public:
-	GStatsPlugin(struct GC_Configuration *config, struct GE_Context *errorContext);
+	GStatsPlugin(struct GNUNET_GC_Configuration *config, struct GNUNET_GE_Context *errorContext);
 	virtual ~GStatsPlugin();
 
 protected slots:
-  void refresh();
+  void processStat(const char *name, qulonglong value);
 
 protected:
-  struct GC_Configuration *config;
-  struct GE_Context *errorContext;
+  struct GNUNET_GC_Configuration *config;
+  struct GNUNET_GE_Context *errorContext;
+  class GStatsThread *statsThread;
 };
 
 #endif /*STATSPLUGIN_H_*/
